utility Package
===============

:mod:`utility` Package
----------------------

.. automodule:: numba.utility
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`math_utilities` Module
----------------------------

.. automodule:: numba.utility.math_utilities
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`virtuallookup` Module
---------------------------

.. automodule:: numba.utility.virtuallookup
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.utility.cbuilder

